@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 import atexit
 import functools
 import inspect
@@ -45,7 +43,7 @@ except ImportError:
 try:
     from ._version import version as __version__
 except ImportError:
-    __version__ = '3.3.8'
+    __version__ = '3.7.0'
 
 __all__ = (
     'And',
@@ -64,19 +62,21 @@ __all__ = (
     'VarsPrinter',
     'VarsSnooper',
     'When',
-
     'stop',
     'trace',
 )
 THREADING_SUPPORT_ALIASES = (
-    'threading_support', 'threads_support', 'thread_support',
-    'threadingsupport', 'threadssupport', 'threadsupport',
-    'threading', 'threads', 'thread',
-)
-TRACER_OPTION_NAMES = THREADING_SUPPORT_ALIASES + (
-    'clear_env_var',
-    'profile',
+    'threading_support',
+    'threads_support',
+    'thread_support',
+    'threadingsupport',
+    'threadssupport',
+    'threadsupport',
+    'threading',
+    'threads',
+    'thread',
 )
+TRACER_OPTION_NAMES = (*THREADING_SUPPORT_ALIASES, 'clear_env_var', 'profile')
 _last_tracer = None
 _default_trace_args = None
 _default_config = {}
@@ -86,27 +86,30 @@ _default_stream = sys.stderr
 def _embed_via_environment():
     if 'PYTHONHUNTER' in os.environ:
         try:
-            eval('trace({[PYTHONHUNTER]})'.format(os.environ), {
-                'And': And,
-                'Backlog': Backlog,
-                'CallPrinter': CallPrinter,
-                'CodePrinter': CodePrinter,
-                'Debugger': Debugger,
-                'ErrorSnooper': ErrorSnooper,
-                'From': From,
-                'Manhole': Manhole,
-                'Not': Not,
-                'Or': Or,
-                'Q': Q,
-                'Query': Query,
-                'StackPrinter': StackPrinter,
-                'VarsPrinter': VarsPrinter,
-                'VarsSnooper': VarsSnooper,
-                'When': When,
-                'trace': trace,
-            })
+            eval(
+                f'trace({os.environ["PYTHONHUNTER"]})',
+                {
+                    'And': And,
+                    'Backlog': Backlog,
+                    'CallPrinter': CallPrinter,
+                    'CodePrinter': CodePrinter,
+                    'Debugger': Debugger,
+                    'ErrorSnooper': ErrorSnooper,
+                    'From': From,
+                    'Manhole': Manhole,
+                    'Not': Not,
+                    'Or': Or,
+                    'Q': Q,
+                    'Query': Query,
+                    'StackPrinter': StackPrinter,
+                    'VarsPrinter': VarsPrinter,
+                    'VarsSnooper': VarsSnooper,
+                    'When': When,
+                    'trace': trace,
+                },
+            )
         except Exception as exc:
-            sys.stderr.write('Failed to load hunter from PYTHONHUNTER environ variable {[PYTHONHUNTER]!r}: {!r}\n'.format(os.environ, exc))
+            sys.stderr.write(f'Failed to load hunter from PYTHONHUNTER environ variable {os.environ["PYTHONHUNTER"]!r}: {exc!r}\n')
 
 
 def _prepare_config(*args, **kwargs):
@@ -142,14 +145,12 @@ def _prepare_config(*args, **kwargs):
             continue
 
         _default_config.pop(key)
-        sys.stderr.write('Discarded config from PYTHONHUNTERCONFIG {}={!r}: Unknown option\n'.format(
-            key, value))
+        sys.stderr.write(f'Discarded config from PYTHONHUNTERCONFIG {key}={value!r}: Unknown option\n')
     for position, predicate in enumerate(args):
         if callable(predicate):
             predicates.append(predicate)
         else:
-            sys.stderr.write('Discarded config from PYTHONHUNTERCONFIG {} (position {}): Not a callable\n'.format(
-                predicate, position))
+            sys.stderr.write(f'Discarded config from PYTHONHUNTERCONFIG {predicate} (position {position}): Not a callable\n')
 
     return predicates, options
 
@@ -169,24 +170,21 @@ def Q(*predicates, **query):
 
     for p in predicates:
         if not callable(p):
-            raise TypeError('Predicate {0!r} is not callable.'.format(p))
+            raise TypeError(f'Predicate {p!r} is not callable.')
 
     for a in optional_actions:
         if not callable(a):
-            raise TypeError('Action {0!r} is not callable.'.format(a))
+            raise TypeError(f'Action {a!r} is not callable.')
 
     if predicates:
-        predicates = tuple(
-            p() if inspect.isclass(p) and issubclass(p, Action) else p
-            for p in predicates
-        )
+        predicates = tuple(p() if inspect.isclass(p) and issubclass(p, Action) else p for p in predicates)
         if any(isinstance(p, (CallPrinter, CodePrinter)) for p in predicates):
             # the user provided an action as a filter, remove the action then to prevent double output
             for action in optional_actions:
                 if action in (CallPrinter, CodePrinter) or isinstance(action, (CallPrinter, CodePrinter)):
                     optional_actions.remove(action)
         if query:
-            predicates += Query(**query),
+            predicates += (Query(**query),)
 
         result = And(*predicates)
     else:
@@ -201,7 +199,7 @@ def Q(*predicates, **query):
 def _merge(*predicates, **query):
     if predicates:
         if query:
-            predicates += Query(**query),
+            predicates += (Query(**query),)
         return And(*predicates)
     else:
         return Query(**query)
@@ -240,7 +238,7 @@ def And(*predicates, **kwargs):
          :class:`hunter.predicates.And`
     """
     if kwargs:
-        predicates += Query(**kwargs),
+        predicates += (Query(**kwargs),)
     return _flatten(_And, *predicates)
 
 
@@ -278,7 +276,7 @@ def Not(*predicates, **kwargs):
          :class:`hunter.predicates.Not`
     """
     if kwargs:
-        predicates += Query(**kwargs),
+        predicates += (Query(**kwargs),)
     if len(predicates) > 1:
         return _Not(_flatten(_And, *predicates))
     else:
@@ -306,12 +304,11 @@ def From(condition=None, predicate=None, watermark=0, **kwargs):
     """
     if predicate is None and condition is None:
         condition_kwargs = {key: value for key, value in kwargs.items() if not key.startswith('depth') and not key.startswith('calls')}
-        predicate_kwargs = {key: value for key, value in kwargs.items() if key.startswith('depth') or key.startswith('calls')}
+        predicate_kwargs = {key: value for key, value in kwargs.items() if key.startswith(('depth', 'calls'))}
         return _From(Q(**condition_kwargs), Q(**predicate_kwargs), watermark)
     else:
         if kwargs:
-            raise TypeError("Unexpected arguments {}. Don't combine positional with keyword arguments.".format(
-                kwargs.keys()))
+            raise TypeError(f"Unexpected arguments {kwargs.keys()}. Don't combine positional with keyword arguments.")
         return _From(condition, predicate, watermark)
 
 
@@ -343,9 +340,18 @@ def Backlog(*conditions, **kwargs):
     strip = kwargs.pop('strip', True)
     vars = kwargs.pop('vars', False)
     if not conditions and not kwargs:
-        raise TypeError('Backlog needs at least 1 condition '
-                        "(it doesn't have any effect without one besides making everything incredibly slow).")
-    return _Backlog(_merge(*conditions, **kwargs), size=size, stack=stack, vars=vars, strip=strip, action=action, filter=filter)
+        raise TypeError(
+            'Backlog needs at least 1 condition ' "(it doesn't have any effect without one besides making everything incredibly slow)."
+        )
+    return _Backlog(
+        _merge(*conditions, **kwargs),
+        size=size,
+        stack=stack,
+        vars=vars,
+        strip=strip,
+        action=action,
+        filter=filter,
+    )
 
 
 def stop():
@@ -355,7 +361,7 @@ def stop():
     global _last_tracer
 
     if _last_tracer is None:
-        warnings.warn('There is no tracer to stop.')
+        warnings.warn('There is no tracer to stop.', stacklevel=2)
     else:
         _last_tracer.stop()
         _last_tracer = None
@@ -426,7 +432,7 @@ def trace(*predicates, **options):
     _last_tracer = Tracer(threading_support, profiling_mode)
 
     @atexit.register
-    def atexit_cleanup(ref=weakref.ref(_last_tracer)):
+    def atexit_cleanup(ref=weakref.ref(_last_tracer)):  # noqa: B008
         maybe_tracer = ref()
         if maybe_tracer is not None:
             maybe_tracer.stop()
@@ -458,27 +464,63 @@ def wrap(function_to_trace=None, **trace_options):
     """
 
     def tracing_decorator(func):
-        @functools.wraps(func)
-        def tracing_wrapper(*args, **kwargs):
-            predicates = []
-            local = trace_options.pop('local', False)
-            if local:
-                predicates.append(Query(depth_lt=2))
-            predicates.append(
-                From(
-                    Query(kind='call'),
-                    Not(When(
+        predicates = []
+        local = trace_options.pop('local', False)
+        if local:
+            predicates.append(Query(depth_lt=2))
+        predicates.append(
+            From(
+                Query(kind='call', function=func.__name__),
+                Not(
+                    When(
                         Query(calls_gt=0, depth=0) & Not(Query(kind='return')),
-                        Stop
-                    )),
-                    watermark=-1
-                )
+                        Stop,
+                    )
+                ),
+                watermark=-1,
             )
-            local_tracer = trace(*predicates, **trace_options)
-            try:
-                return func(*args, **kwargs)
-            finally:
-                local_tracer.stop()
+        )
+
+        if inspect.isasyncgenfunction(func):
+
+            @functools.wraps(func)
+            async def tracing_wrapper(*args, **kwargs):
+                local_tracer = trace(*predicates, **trace_options)
+                try:
+                    async for item in func(*args, **kwargs):
+                        yield item
+                finally:
+                    local_tracer.stop()
+
+        elif inspect.iscoroutinefunction(func):
+
+            @functools.wraps(func)
+            async def tracing_wrapper(*args, **kwargs):
+                local_tracer = trace(*predicates, **trace_options)
+                try:
+                    return await func(*args, **kwargs)
+                finally:
+                    local_tracer.stop()
+
+        elif inspect.isgeneratorfunction(func):
+
+            @functools.wraps(func)
+            def tracing_wrapper(*args, **kwargs):
+                local_tracer = trace(*predicates, **trace_options)
+                try:
+                    yield from func(*args, **kwargs)
+                finally:
+                    local_tracer.stop()
+
+        else:
+
+            @functools.wraps(func)
+            def tracing_wrapper(*args, **kwargs):
+                local_tracer = trace(*predicates, **trace_options)
+                try:
+                    return func(*args, **kwargs)
+                finally:
+                    local_tracer.stop()
 
         return tracing_wrapper
 
@@ -490,15 +532,15 @@ def wrap(function_to_trace=None, **trace_options):
 
 def load_config(*args, **kwargs):
     global _default_trace_args
-    try:
-        if args or kwargs:
-            _default_trace_args = _prepare_config(*args, **kwargs)
-        else:
-            _default_trace_args = eval('_prepare_config({})'.format(os.environ.get('PYTHONHUNTERCONFIG', '')))
-    except Exception as exc:
-        sys.stderr.write('Failed to load hunter config from PYTHONHUNTERCONFIG {[PYTHONHUNTERCONFIG]!r}: {!r}\n'.format(
-            os.environ, exc))
-        _default_trace_args = (), ()
+    if args or kwargs:
+        _default_trace_args = _prepare_config(*args, **kwargs)
+    else:
+        config = os.environ.get('PYTHONHUNTERCONFIG', '')
+        try:
+            _default_trace_args = eval(f'_prepare_config({config})')
+        except Exception as exc:
+            sys.stderr.write(f'Failed to load hunter config from PYTHONHUNTERCONFIG {config!r}: {exc!r}\n')
+            _default_trace_args = (), ()
 
 
 load_config()
