@@ -1,5 +1,4 @@
-from __future__ import print_function
-
+# ruff: noqa: S103 S108 S603
 import argparse
 import errno
 import json
@@ -13,6 +12,8 @@ from contextlib import closing
 from contextlib import contextmanager
 from subprocess import check_call
 
+import hunter
+
 if platform.system() == 'Windows':
     print('ERROR: This tool does not work on Windows.', file=sys.stderr)
     sys.exit(1)
@@ -21,11 +22,7 @@ else:
     from manhole import get_peercred
     from manhole.cli import parse_signal
 
-    from . import stop
-    from . import trace
-    from . import config
-
-__all__ = 'install',
+__all__ = ('install',)
 
 
 def install(**kwargs):
@@ -34,7 +31,7 @@ def install(**kwargs):
     manhole.install(**kwargs)
 
 
-class RemoteStream(object):
+class RemoteStream:
     def __init__(self, path, isatty, encoding):
         self._sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         self._sock.connect(path)
@@ -50,9 +47,11 @@ class RemoteStream(object):
                 data = data.decode('ascii', 'replace')
             self._sock.send(data.encode(self._encoding))
         except Exception as exc:
-            print('Hunter failed to send trace output {!r} (encoding: {!r}): {!r}. Stopping tracer.'.format(
-                data, self._encoding, exc), file=sys.stderr)
-            stop()
+            print(
+                f'Hunter failed to send trace output {data!r} (encoding: {self._encoding!r}): {exc!r}. Stopping tracer.',
+                file=sys.stderr,
+            )
+            hunter.stop()
 
     def flush(self):
         pass
@@ -79,12 +78,20 @@ def manhole_bootstrap(args, activation_payload, deactivation_payload):
 def gdb_bootstrap(args, activation_payload, deactivation_payload):
     print('WARNING: Using GDB may deadlock the process or create unpredictable results!')
     activation_command = [
-        'gdb', '-p', str(args.pid), '-batch',
-        '-ex', 'call (void)Py_AddPendingCall(PyRun_SimpleString, {})'.format(json.dumps(activation_payload)),
+        'gdb',
+        '-p',
+        str(args.pid),
+        '-batch',
+        '-ex',
+        f'call (void)Py_AddPendingCall(PyRun_SimpleString, {json.dumps(activation_payload)})',
     ]
     deactivation_command = [
-        'gdb', '-p', str(args.pid), '-batch',
-        '-ex', 'call (void)Py_AddPendingCall(PyRun_SimpleString, {})'.format(json.dumps(deactivation_payload)),
+        'gdb',
+        '-p',
+        str(args.pid),
+        '-batch',
+        '-ex',
+        f'call (void)Py_AddPendingCall(PyRun_SimpleString, {json.dumps(deactivation_payload)})',
     ]
     check_call(activation_command)
     try:
@@ -97,62 +104,90 @@ def connect_manhole(pid, timeout, signal):
     os.kill(pid, signal)
 
     start = time.time()
-    uds_path = '/tmp/manhole-{}'.format(pid)
+    uds_path = f'/tmp/manhole-{pid}'
     conn = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
     conn.settimeout(timeout)
     while time.time() - start < timeout:
         try:
             conn.connect(uds_path)
-        except (OSError, socket.error) as exc:
+        except OSError as exc:
             if exc.errno not in (errno.ENOENT, errno.ECONNREFUSED):
-                print('Failed to connect to {!r}: {!r}'.format(uds_path, exc), file=sys.stderr)
+                print(
+                    f'Failed to connect to {uds_path!r}: {exc!r}',
+                    file=sys.stderr,
+                )
         else:
             break
     else:
-        print('Failed to connect to {!r}: Timeout'.format(uds_path), file=sys.stderr)
+        print(
+            f'Failed to connect to {uds_path!r}: Timeout',
+            file=sys.stderr,
+        )
         sys.exit(5)
     return conn
 
 
 def activate(sink_path, isatty, encoding, options):
-    stream = config.DEFAULT_STREAM = RemoteStream(sink_path, isatty, encoding)
+    stream = hunter._default_stream = RemoteStream(sink_path, isatty, encoding)
     try:
         stream.write('Output stream active. Starting tracer ...\n\n')
-        eval('trace({})'.format(options))
+        eval(f'hunter.trace({options})')
     except Exception as exc:
-        stream.write('Failed to activate: {!r}. {}\n'.format(
-            exc,
-            'Tracer options where: {}.'.format(options) if options else 'No tracer options.'
-        ))
-        config.DEFAULT_STREAM = sys.stderr
+        stream.write(
+            'Failed to activate: {!r}. {}\n'.format(
+                exc,
+                f'Tracer options where: {options}.' if options else 'No tracer options.',
+            )
+        )
+        hunter._default_stream = sys.stderr
         raise
 
 
-trace,  # used in eval above
-
-
 def deactivate():
-    config.DEFAULT_STREAM = sys.stderr
-    stop()
+    hunter._default_stream = sys.stderr
+    hunter.stop()
 
 
 parser = argparse.ArgumentParser(description='Trace a process.')
-parser.add_argument('-p', '--pid', metavar='PID', type=int, required=True,
-                    help='A numerical process id.')
+parser.add_argument(
+    '-p',
+    '--pid',
+    metavar='PID',
+    type=int,
+    required=True,
+    help='A numerical process id.',
+)
 parser.add_argument('options', metavar='OPTIONS', nargs='*')
-parser.add_argument('-t', '--timeout', dest='timeout', default=1, type=float,
-                    help='Timeout to use. Default: %(default)s seconds.')
-parser.add_argument('--gdb', dest='gdb', action='store_true',
-                    help='Use GDB to activate tracing. WARNING: it may deadlock the process!')
-parser.add_argument('-s', '--signal', dest='signal', type=parse_signal, metavar='SIGNAL', default=signal.SIGURG,
-                    help='Send the given SIGNAL to the process before connecting. Default: %(default)s.')
+parser.add_argument(
+    '-t',
+    '--timeout',
+    dest='timeout',
+    default=1,
+    type=float,
+    help='Timeout to use. Default: %(default)s seconds.',
+)
+parser.add_argument(
+    '--gdb',
+    dest='gdb',
+    action='store_true',
+    help='Use GDB to activate tracing. WARNING: it may deadlock the process!',
+)
+parser.add_argument(
+    '-s',
+    '--signal',
+    dest='signal',
+    type=parse_signal,
+    metavar='SIGNAL',
+    default=signal.SIGURG,
+    help='Send the given SIGNAL to the process before connecting. Default: %(default)s.',
+)
 
 
 def main():
     args = parser.parse_args()
 
     sink = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-    sink_path = '/tmp/hunter-{}'.format(os.getpid())
+    sink_path = f'/tmp/hunter-{os.getpid()}'
     sink.bind(sink_path)
     sink.listen(1)
     os.chmod(sink_path, 0o777)
@@ -164,7 +199,7 @@ def main():
         sink_path,
         sys.stdout.isatty(),
         encoding,
-        ','.join(i.strip(',') for i in args.options)
+        ','.join(i.strip(',') for i in args.options),
     )
     with bootstrapper(args, payload, 'from hunter import remote; remote.deactivate()'):
         conn, _ = sink.accept()
@@ -172,10 +207,12 @@ def main():
         pid, _, _ = get_peercred(conn)
         if pid:
             if pid != args.pid:
-                raise Exception('Unexpected pid {!r} connected to output socket. Was expecting {!r}.'.format(
-                     pid, args.pid))
+                raise Exception(f'Unexpected pid {pid!r} connected to output socket. Was expecting {args.pid!r}.')
         else:
-            print('WARNING: Failed to get pid of connected process.', file=sys.stderr)
+            print(
+                'WARNING: Failed to get pid of connected process.',
+                file=sys.stderr,
+            )
         data = conn.recv(1024)
         while data:
             stdout.write(data)
